@@ -108,6 +108,13 @@ $Conf{UmaskMode} = 027;
 #
 # The default value is every hour except midnight.
 #
+# The first entry of $Conf{WakeupSchedule} is when BackupPC_nightly
+# is run.  No other backups can run while BackupPC_nightly is
+# running.  You might want to re-arrange the entries in
+# $Conf{WakeupSchedule} (they don't have to be ascending) so that
+# the first entry is when you want BackupPC_nightly to run
+# (eg: when you don't expect a lot of regular backups to run).
+#
 $Conf{WakeupSchedule} = [1..23];
 
 #
@@ -133,6 +140,50 @@ $Conf{MaxUserBackups} = 4;
 #
 $Conf{MaxPendingCmds} = 10;
 
+#
+# How many BackupPC_nightly processes to run in parallel.
+#
+# Each night, at the first wakeup listed in $Conf{WakeupSchedule},
+# BackupPC_nightly is run.  Its job is to remove unneeded files
+# in the pool, ie: files that only have one link.  To avoid race
+# conditions, BackupPC_nightly runs only when there are no backups
+# running, and no backups will start while it runs.
+#
+# So to reduce the elapsed time, you might want to increase this
+# setting to run several BackupPC_nightly processes in parallel
+# (eg: 4, or even 8).
+#
+$Conf{MaxBackupPCNightlyJobs} = 2;
+
+#
+# How many days (runs) it takes BackupPC_nightly to traverse the
+# entire pool.  Normally this is 1, which means every night it runs,
+# it does traverse the entire pool removing unused pool files.
+#
+# Other valid values are 2, 4, 8, 16.  This causes BackupPC_nightly to
+# traverse 1/2, 1/4, 1/8 or 1/16th of the pool each night, meaning it
+# takes 2, 4, 8 or 16 days to completely traverse the pool.  The
+# advantage is that each night the running time of BackupPC_nightly
+# is reduced roughly in proportion, since the total job is split
+# over multiple days.  The disadvantage is that unused pool files
+# take longer to get deleted, which will slightly increase disk
+# usage.
+#
+# Note that even when $Conf{BackupPCNightlyPeriod} > 1, BackupPC_nightly
+# still runs every night.  It just does less work each time it runs.
+#
+# Examples:
+#
+#    $Conf{BackupPCNightlyPeriod} = 1;   # entire pool is checked every night
+#
+#    $Conf{BackupPCNightlyPeriod} = 2;   # two days to complete pool check
+#                                        # (different half each night)
+#
+#    $Conf{BackupPCNightlyPeriod} = 4;   # four days to complete pool check
+#                                        # (different quarter each night)
+#
+$Conf{BackupPCNightlyPeriod} = 1;
+
 #
 # Maximum number of log files we keep around in log directory.
 # These files are aged nightly.  A setting of 14 means the log
@@ -160,6 +211,16 @@ $Conf{DfPath} = '/bin/df';
 #
 $Conf{DfCmd} = '$dfPath $topDir';
 
+#
+# Full path to various commands for archiving
+#
+
+$Conf{SplitPath} = '/usr/bin/split';
+$Conf{ParPath}   = '/usr/bin/par2';
+$Conf{CatPath}   = '/bin/cat';
+$Conf{GzipPath}  = '/bin/gzip';
+$Conf{Bzip2Path} = '/usr/bin/bzip2';
+
 #
 # Maximum threshold for disk utilization on the __TOPDIR__ filesystem.
 # If the output from $Conf{DfPath} reports a percentage larger than
@@ -231,7 +292,7 @@ $Conf{BackupPCUserVerify} = 1;
 #
 # Maximum number of hardlinks supported by the $TopDir file system
 # that BackupPC uses.  Most linux or unix file systems should support
-# at least 32000 hardlinks per file, or 64K in other cases.  If a pool
+# at least 32000 hardlinks per file, or 64000 in other cases.  If a pool
 # file already has this number of hardlinks, a new pool file is created
 # so that new hardlinks can be accommodated.  This limit will only
 # be hit if an identical file appears at least this number of times
@@ -327,10 +388,6 @@ $Conf{TarShareName} = '/';
 # being backed up (eg: a retired machine), but you wish to keep the
 # last backups available for browsing or restoring to other machines.
 #
-# Also, you might create a virtual client (by setting $Conf{ClientNameAlias})
-# for restoring to a DVD or permanent media and you would set
-# $Conf{FullPeriod} to -2 so that it is never backed up.
-#
 $Conf{FullPeriod} = 6.97;
 
 #
@@ -351,8 +408,70 @@ $Conf{IncrPeriod} = 0.97;
 # extra old backups will be removed.
 #
 # If filling of incremental dumps is off the oldest backup always
-# has to be a full (ie: filled) dump.  This might mean an extra full
-# dump is kept until the second oldest (incremental) dump expires.
+# has to be a full (ie: filled) dump.  This might mean one or two
+# extra full dumps are kept until the oldest incremental backups expire.
+#
+# Exponential backup expiry is also supported.  This allows you to specify:
+#
+#   - num fulls to keep at intervals of 1 * $Conf{FullPeriod}, followed by
+#   - num fulls to keep at intervals of 2 * $Conf{FullPeriod},
+#   - num fulls to keep at intervals of 4 * $Conf{FullPeriod},
+#   - num fulls to keep at intervals of 8 * $Conf{FullPeriod},
+#   - num fulls to keep at intervals of 16 * $Conf{FullPeriod},
+#
+# and so on.  This works by deleting every other full as each expiry
+# boundary is crossed.
+#
+# Exponential expiry is specified using an array for $Conf{FullKeepCnt}:
+#
+#   $Conf{FullKeepCnt} = [4, 2, 3];
+#
+# Entry #n specifies how many fulls to keep at an interval of
+# 2^n * $Conf{FullPeriod} (ie: 1, 2, 4, 8, 16, 32, ...).
+#
+# The example above specifies keeping 4 of the most recent full backups
+# (1 week interval) two full backups at 2 week intervals, and 3 full
+# backups at 4 week intervals, eg:
+#
+#    full 0 19 weeks old   \
+#    full 1 15 weeks old    >---  3 backups at 4 * $Conf{FullPeriod}
+#    full 2 11 weeks old   / 
+#    full 3  7 weeks old   \____  2 backups at 2 * $Conf{FullPeriod}
+#    full 4  5 weeks old   /
+#    full 5  3 weeks old   \
+#    full 6  2 weeks old    \___  4 backups at 1 * $Conf{FullPeriod}
+#    full 7  1 week old     /
+#    full 8  current       /
+#
+# On a given week the spacing might be less than shown as each backup
+# ages through each expiry period.  For example, one week later, a
+# new full is completed and the oldest is deleted, giving:
+#
+#    full 0 16 weeks old   \
+#    full 1 12 weeks old    >---  3 backups at 4 * $Conf{FullPeriod}
+#    full 2  8 weeks old   / 
+#    full 3  6 weeks old   \____  2 backups at 2 * $Conf{FullPeriod}
+#    full 4  4 weeks old   /
+#    full 5  3 weeks old   \
+#    full 6  2 weeks old    \___  4 backups at 1 * $Conf{FullPeriod}
+#    full 7  1 week old     /
+#    full 8  current       /
+#
+# You can specify 0 as a count (except in the first entry), and the
+# array can be as long as you wish.  For example:
+#
+#   $Conf{FullKeepCnt} = [4, 0, 4, 0, 0, 2];
+#
+# This will keep 10 full dumps, 4 most recent at 1 * $Conf{FullPeriod},
+# followed by 4 at an interval of 4 * $Conf{FullPeriod} (approx 1 month
+# apart), and then 2 at an interval of 32 * $Conf{FullPeriod} (approx
+# 7-8 months apart).
+#
+# Example: these two settings are equivalent and both keep just
+# the four most recent full dumps:
+#
+#    $Conf{FullKeepCnt} = 4;
+#    $Conf{FullKeepCnt} = [4];
 #
 $Conf{FullKeepCnt} = 1;
 
@@ -361,8 +480,12 @@ $Conf{FullKeepCnt} = 1;
 # we keep at least $Conf{FullKeepCntMin} full backups no matter how old
 # they are.
 #
+# Note that $Conf{FullAgeMax} will be increased to $Conf{FullAgeMax}
+# times $Conf{FullPeriod} if $Conf{FullAgeMax} specifies enough
+# full backups to exceed $Conf{FullAgeMax}.
+#
 $Conf{FullKeepCntMin} = 1;
-$Conf{FullAgeMax}     = 60;
+$Conf{FullAgeMax}     = 90;
 
 #
 # Number of incremental backups to keep.  Must be >= 1.
@@ -381,6 +504,21 @@ $Conf{IncrKeepCnt} = 6;
 $Conf{IncrKeepCntMin} = 1;
 $Conf{IncrAgeMax}     = 30;
 
+#
+# A failed full backup is saved as a partial backup.  The rsync
+# XferMethod can take advantage of the partial full when the next
+# backup is run. This parameter sets the age of the partial full
+# in days: if the partial backup is older than this number of
+# days, then rsync will ignore (not use) the partial full when
+# the next backup is run.  If you set this to a negative value
+# then no partials will be saved.  If you set this to 0, partials
+# will be saved, but will not be used by the next backup.
+#
+# The default setting of 3 days means that a partial older than
+# 3 days is ignored when the next full backup is done.
+#
+$Conf{PartialAgeMax} = 3;
+
 #
 # Whether incremental backups are filled.  "Filling" means that the
 # most recent full (or filled) dump is merged into the new incremental
@@ -422,6 +560,13 @@ $Conf{IncrFill} = 0;
 #
 $Conf{RestoreInfoKeepCnt} = 10;
 
+#
+# Number of archive logs to keep.  BackupPC remembers information
+# about each archive request.  This number per archive client will
+# be kept around before the oldest ones are pruned.
+#
+$Conf{ArchiveInfoKeepCnt} = 10;
+
 #
 # List of directories or files to backup.  If this is defined, only these
 # directories or files will be backed up.
@@ -436,7 +581,7 @@ $Conf{RestoreInfoKeepCnt} = 10;
 # to give a list of directories or files to backup for each share
 # (the share name is the key).  If this is set to just a string or
 # array, and $Conf{SmbShareName} contains multiple share names, then
-# the setting is assumed to apply to only the first share name.
+# the setting is assumed to apply all shares.
 #
 # Examples:
 #    $Conf{BackupFilesOnly} = '/myFiles';
@@ -461,7 +606,7 @@ $Conf{BackupFilesOnly} = undef;
 # to give a list of directories or files to exclude for each share
 # (the share name is the key).  If this is set to just a string or
 # array, and $Conf{SmbShareName} contains multiple share names, then
-# the setting is assumed to apply to only the first share name.
+# the setting is assumed to apply to all shares.
 #
 # The exact behavior is determined by the underlying transport program,
 # smbclient or tar.  For smbclient the exlclude file list is passed into
@@ -478,6 +623,9 @@ $Conf{BackupFilesOnly} = undef;
 # the directory name: a trailing "/" causes the name to not match
 # and the directory will not be excluded.
 #
+# Users report that for smbclient you should specify a directory
+# followed by "/*", eg: "/proc/*", instead of just "/proc".
+#
 # Examples:
 #    $Conf{BackupFilesExclude} = '/temp';
 #    $Conf{BackupFilesExclude} = ['/temp'];     # same as first example
@@ -495,8 +643,7 @@ $Conf{BackupFilesExclude} = undef;
 # each PC a count of consecutive good pings is maintained. Once a PC has
 # at least $Conf{BlackoutGoodCnt} consecutive good pings it is subject
 # to "blackout" and not backed up during hours and days specified by
-# $Conf{BlackoutWeekDays}, $Conf{BlackoutHourBegin} and
-# $Conf{BlackoutHourEnd}.
+# $Conf{BlackoutPeriods}.
 #
 # To allow for periodic rebooting of a PC or other brief periods when a
 # PC is not on the network, a number of consecutive bad pings is allowed
@@ -522,20 +669,59 @@ $Conf{BlackoutBadPingLimit} = 3;
 $Conf{BlackoutGoodCnt}      = 7;
 
 #
-# The default settings specify the blackout period from 7:00am to
-# 7:30pm local time on Mon-Fri.  For $Conf{BlackoutWeekDays},
-# 0 is Sunday, 1 is Monday etc.
+# One or more blackout periods can be specified.  If a client is
+# subject to blackout then no regular (non-manual) backups will
+# be started during any of these periods.  hourBegin and hourEnd
+# specify hours fro midnight and weekDays is a list of days of
+# the week where 0 is Sunday, 1 is Monday etc.
 #
-$Conf{BlackoutHourBegin}    = 7.0;
-$Conf{BlackoutHourEnd}      = 19.5;
-$Conf{BlackoutWeekDays}     = [1, 2, 3, 4, 5];
+# For example:
+#
+#    $Conf{BlackoutPeriods} = [
+#	{
+#	    hourBegin =>  7.0,
+#	    hourEnd   => 19.5,
+#	    weekDays  => [1, 2, 3, 4, 5],
+#	},
+#    ];
+#
+# specifies one blackout period from 7:00am to 7:30pm local time
+# on Mon-Fri.
+#
+# The blackout period can also span midnight by setting
+# hourBegin > hourEnd, eg:
+#
+#    $Conf{BlackoutPeriods} = [
+#	{
+#	    hourBegin =>  7.0,
+#	    hourEnd   => 19.5,
+#	    weekDays  => [1, 2, 3, 4, 5],
+#	},
+#	{
+#	    hourBegin => 23,
+#	    hourEnd   =>  5,
+#	    weekDays  => [5, 6],
+#	},
+#    ];
+#
+# This specifies one blackout period from 7:00am to 7:30pm local time
+# on Mon-Fri, and a second period from 11pm to 5am on Friday and
+# Saturday night.
+#
+$Conf{BlackoutPeriods} = [
+    {
+	hourBegin =>  7.0,
+	hourEnd   => 19.5,
+	weekDays  => [1, 2, 3, 4, 5],
+    },
+];
 
-#   
+#
 # A backup of a share that has zero files is considered fatal. This is
 # used to catch miscellaneous Xfer errors that result in no files being
 # backed up.  If you have shares that might be empty (and therefore an
 # empty backup is valid) you should set this flag to 0.
-#   
+#
 $Conf{BackupZeroFilesIsFatal} = 1;
 
 ###########################################################################
@@ -549,21 +735,33 @@ $Conf{BackupZeroFilesIsFatal} = 1;
 #
 # The valid values are:
 #
-#   - 'smb':    backup and restore via smbclient and the SMB protocol.
-#               Best choice for WinXX.
+#   - 'smb':     backup and restore via smbclient and the SMB protocol.
+#                Easiest choice for WinXX.
 #
-#   - 'rsync':  backup and restore via rsync (via rsh or ssh).
-#               Best choice for linux/unix.  Can also work on WinXX.
+#   - 'rsync':   backup and restore via rsync (via rsh or ssh).
+#                Best choice for linux/unix.  Good choice also for WinXX.
 #
-#   - 'rsyncd': backup and restre via rsync daemon on the client.
-#               Best choice for linux/unix if you have rsyncd running on
-#               the client.  Can also work on WinXX.
+#   - 'rsyncd':  backup and restre via rsync daemon on the client.
+#                Best choice for linux/unix if you have rsyncd running on
+#                the client.  Good choice also for WinXX.
 #
 #   - 'tar':    backup and restore via tar, tar over ssh, rsh or nfs.
 #               Good choice for linux/unix.
 #
+#   - 'archive': host is a special archive host.  Backups are not done.
+#                An archive host is used to archive other host's backups
+#                to permanent media, such as tape, CDR or DVD.
+#               
+#
 $Conf{XferMethod} = 'smb';
 
+#
+# Level of verbosity in Xfer log files.  0 means be quiet, 1 will give
+# will give one line per file, 2 will also show skipped files on
+# incrementals, higher values give more output.
+#
+$Conf{XferLogLevel} = 1;
+
 #
 # Full path for smbclient. Security caution: normal users should not
 # allowed to write to this file or directory.
@@ -577,7 +775,7 @@ $Conf{XferMethod} = 'smb';
 $Conf{SmbClientPath} = '/usr/bin/smbclient';
 
 #
-# Commands to run smbclient for a full dump, incremental dump or a restore.
+# Command to run smbclient for a full dump.
 # This setting only matters if $Conf{XferMethod} = 'smb'.
 #
 # The following variables are substituted at run-time:
@@ -596,10 +794,26 @@ $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -N -d 1'
             . ' -c tarmode\\ full -Tc$X_option - $fileList';
 
+#
+# Command to run smbclient for an incremental dump.
+# This setting only matters if $Conf{XferMethod} = 'smb'.
+#
+# Same variable substitutions are applied as $Conf{SmbClientFullCmd}.
+#
 $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -N -d 1'
 	    . ' -c tarmode\\ full -TcN$X_option $timeStampFile - $fileList';
 
+#
+# Command to run smbclient for a restore.
+# This setting only matters if $Conf{XferMethod} = 'smb'.
+#
+# Same variable substitutions are applied as $Conf{SmbClientFullCmd}.
+#
+# If your smb share is read-only then direct restores will fail.
+# You should set $Conf{SmbClientRestoreCmd} to undef and the
+# corresponding CGI restore option will be removed.
+#
 $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
             . ' $I_option -U $userName -E -N -d 1'
             . ' -c tarmode\\ full -Tx -';
@@ -639,7 +853,7 @@ $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
 #
 # This setting only matters if $Conf{XferMethod} = 'tar'.
 #
-$Conf{TarClientCmd} = '$sshPath -q -n -l root $host'
+$Conf{TarClientCmd} = '$sshPath -q -x -n -l root $host'
                     . ' $tarPath -c -v -f - -C $shareName+'
                     . ' --totals';
 
@@ -692,7 +906,11 @@ $Conf{TarIncrArgs} = '--newer=$incrDate+ $fileList+';
 #
 # This setting only matters if $Conf{XferMethod} = "tar".
 #
-$Conf{TarClientRestoreCmd} = '$sshPath -q -l root $host'
+# If you want to disable direct restores using tar, you should set
+# $Conf{TarClientRestoreCmd} to undef and the corresponding CGI
+# restore option will be removed.
+#
+$Conf{TarClientRestoreCmd} = '$sshPath -q -x -l root $host'
 		   . ' $tarPath -x -p --numeric-owner --same-owner'
 		   . ' -v -f - -C $shareName+';
 
@@ -724,7 +942,7 @@ $Conf{RsyncClientPath} = '/bin/rsync';
 #
 # This setting only matters if $Conf{XferMethod} = 'rsync'.
 #
-$Conf{RsyncClientCmd} = '$sshPath -l root $host $rsyncPath $argList+';
+$Conf{RsyncClientCmd} = '$sshPath -q -x -l root $host $rsyncPath $argList+';
 
 #
 # Full command to run rsync for restore on the client.  The following
@@ -741,7 +959,7 @@ $Conf{RsyncClientCmd} = '$sshPath -l root $host $rsyncPath $argList+';
 #
 # This setting only matters if $Conf{XferMethod} = 'rsync'.
 #
-$Conf{RsyncClientRestoreCmd} = '$sshPath -l root $host $rsyncPath $argList+';
+$Conf{RsyncClientRestoreCmd} = '$sshPath -q -x -l root $host $rsyncPath $argList+';
 
 #
 # Share name to backup.  For $Conf{XferMethod} = "rsync" this should
@@ -789,6 +1007,29 @@ $Conf{RsyncdPasswd} = '';
 #
 $Conf{RsyncdAuthRequired} = 1;
 
+#
+# When rsync checksum caching is enabled (by adding the
+# --checksum-seed=32761 option to $Conf{RsyncArgs}), the cached
+# checksums can be occaisonally verified to make sure the file
+# contents matches the cached checksums.  This is to avoid the
+# risk that disk problems might cause the pool file contents to
+# get corrupted, but the cached checksums would make BackupPC
+# think that the file still matches the client.
+#
+# This setting is the probability (0 means never and 1 means always)
+# that a file will be rechecked.  Setting it to 0 means the checksums
+# will not be rechecked (unless there is a phase 0 failure).  Setting
+# it to 1 (ie: 100%) means all files will be checked, but that is
+# not a desirable setting since you are better off simply turning
+# caching off (ie: remove the --checksum-seed option).
+#   
+# The default of 0.01 means 1% (on average) of the files during a full
+# backup will have their cached checksum re-checked.
+#   
+# This setting has no effect unless checksum caching is turned on.
+#   
+$Conf{RsyncCsumCacheVerifyProb} = 0.01;
+
 #
 # Arguments to rsync for backup.  Do not edit the first set unless you
 # have a thorough understanding of how File::RsyncP works.
@@ -816,6 +1057,14 @@ $Conf{RsyncArgs} = [
             '--times',
             '--block-size=2048',
             '--recursive',
+
+	    #
+	    # If you are using a patched client rsync that supports the
+	    # --checksum-seed option (see http://backuppc.sourceforge.net),
+	    # then uncomment this to enabled rsync checksum cachcing
+	    #
+	    #'--checksum-seed=32761',
+
 	    #
 	    # Add additional arguments here
 	    #
@@ -825,35 +1074,106 @@ $Conf{RsyncArgs} = [
 # Arguments to rsync for restore.  Do not edit the first set unless you
 # have a thorough understanding of how File::RsyncP works.
 #
+# If you want to disable direct restores using rsync (eg: is the module
+# is read-only), you should set $Conf{RsyncRestoreArgs} to undef and
+# the corresponding CGI restore option will be removed.
 #
 $Conf{RsyncRestoreArgs} = [
 	    #
 	    # Do not edit these!
 	    #
-	    "--numeric-ids",
-	    "--perms",
-	    "--owner",
-	    "--group",
-	    "--devices",
-	    "--links",
-	    "--times",
-	    "--block-size=2048",
-	    "--relative",
-	    "--ignore-times",
-	    "--recursive",
+	    '--numeric-ids',
+	    '--perms',
+	    '--owner',
+	    '--group',
+	    '--devices',
+	    '--links',
+	    '--times',
+	    '--block-size=2048',
+	    '--relative',
+	    '--ignore-times',
+	    '--recursive',
+
+	    #
+	    # If you are using a patched client rsync that supports the
+	    # --checksum-seed option (see http://backuppc.sourceforge.net),
+	    # then uncomment this to enabled rsync checksum cachcing
+	    #
+	    #'--checksum-seed=32761',
+
 	    #
 	    # Add additional arguments here
 	    #
 ];
 
 #
-# Amount of verbosity in Rsync Xfer log files.  0 means be quiet,
-# 1 will give will give one line per file, 2 will also show skipped
-# files on incrementals, higher values give more output.  10 will
-# include byte dumps of all data read/written, which will make the
-# log files huge.
+# Archive Destination
 #
-$Conf{RsyncLogLevel} = 1;
+# The Destination of the archive
+# e.g. /tmp for file archive or /dev/nst0 for device archive
+#
+$Conf{ArchiveDest} = '/tmp';
+
+#
+# Archive Compression type
+#
+# The valid values are:
+#
+#   - 'none':  No Compression
+#
+#   - 'gzip':  Medium Compression. Recommended.
+#
+#   - 'bzip2': High Compression but takes longer.
+#
+$Conf{ArchiveComp} = 'gzip';
+
+#
+# Archive Parity Files
+#
+# The amount of Parity data to generate, as a percentage
+# of the archive size.
+# Uses the commandline par2 (par2cmdline) available from
+# http://parchive.sourceforge.net
+#
+# Only useful for file dumps.
+#
+# Set to 0 to disable this feature.
+#
+$Conf{ArchivePar} = 0;
+
+#
+# Archive Size Split
+#
+# Only for file archives. Splits the output into 
+# the specified size * 1,000,000.
+# e.g. to split into 650,000,000 bytes, specify 650 below.
+# 
+# If the value is 0, or if $Conf{ArchiveDest} is an existing file or
+# device (e.g. a streaming tape drive), this feature is disabled.
+#
+$Conf{ArchiveSplit} = 0;
+
+#
+# Archive Command
+#
+# This is the command that is called to actually run the archive process
+# for each host.  The following variables are substituted at run-time:
+#
+#   $Installdir    The installation directory of BackupPC
+#   $tarCreatePath The path to BackupPC_tarCreate
+#   $splitpath     The path to the split program
+#   $parpath       The path to the par2 program
+#   $host          The host to archive
+#   $backupnumber  The backup number of the host to archive
+#   $compression   The path to the compression program
+#   $compext       The extension assigned to the compression type
+#   $splitsize     The number of bytes to split archives into
+#   $archiveloc    The location to put the archive
+#   $parfile       The amount of parity data to create (percentage)
+#
+$Conf{ArchiveClientCmd} = '$Installdir/bin/BackupPC_archiveHost'
+	. ' $tarCreatePath $splitpath $parpath $host $backupnumber'
+	. ' $compression $compext $splitsize $archiveloc $parfile *';
 
 #
 # Full path for ssh. Security caution: normal users should not
@@ -942,6 +1262,25 @@ $Conf{PingPath} = '/bin/ping';
 #
 $Conf{PingCmd} = '$pingPath -c 1 $host';
 
+#
+# Path to init.d script and command to use that script to start the
+# server from the CGI interface.  The following variables are substituted
+# at run-time:
+#
+#   $sshPath           path to ssh ($Conf{SshPath})
+#   $serverHost        same as $Conf{ServerHost}
+#   $serverInitdPath   path to init.d script ($Conf{ServerInitdPath})
+#
+# Example:
+#
+# $Conf{ServerInitdPath}     = '/etc/init.d/backuppc';
+# $Conf{ServerInitdStartCmd} = '$sshPath -q -x -l root $serverHost'
+#                            . ' $serverInitdPath start'
+#                            . ' < /dev/null >& /dev/null';
+#
+$Conf{ServerInitdPath} = '';
+$Conf{ServerInitdStartCmd} = '';
+
 #
 # Compression level to use on files.  0 means no compression.  Compression
 # levels can be from 1 (least cpu time, slightly worse compression) to
@@ -1020,7 +1359,7 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 # shut down and restart a database server, or to dump a database
 # to files for backup.  Example:
 #
-#    $Conf{DumpPreUserCmd} = '$sshPath -l root $host /usr/bin/dumpMysql';
+#    $Conf{DumpPreUserCmd} = '$sshPath -q -x -l root $host /usr/bin/dumpMysql';
 #
 # The following variable substitutions are made at run time for
 # $Conf{DumpPreUserCmd} and $Conf{DumpPostUserCmd}:
@@ -1037,6 +1376,7 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 #        $shares       list of all the share names
 #        $XferMethod   value of $Conf{XferMethod} (eg: tar, rsync, smb)
 #        $sshPath      value of $Conf{SshPath},
+#        $cmdType      set to DumpPreUserCmd or DumpPostUserCmd
 #
 # The following variable substitutions are made at run time for
 # $Conf{RestorePreUserCmd} and $Conf{RestorePostUserCmd}:
@@ -1058,11 +1398,34 @@ $Conf{MaxOldPerPCLogFiles} = 12;
 #        $pathHdrSrc   common starting path of restore source
 #        $pathHdrDest  common starting path of destination
 #        $fileList     list of files being restored
+#        $cmdType      set to RestorePreUserCmd or RestorePostUserCmd
+#
+# The following variable substitutions are made at run time for
+# $Conf{ArchivePreUserCmd} and $Conf{ArchivePostUserCmd}:
+#
+#        $client       client name being backed up
+#        $xferOK       1 if the archive succeeded, 0 if it didn't
+#        $host         Name of the archive host
+#        $user         user name from the hosts file
+#        $share        the first share name
+#        $XferMethod   value of $Conf{XferMethod} (eg: tar, rsync, smb)
+#        $HostList     list of hosts being archived
+#        $BackupList   list of backup numbers for the hosts being archived
+#        $archiveloc   location where the archive is sent to
+#        $parfile      amount of parity data being generated (percentage)
+#        $compression  compression program being used (eg: cat, gzip, bzip2)
+#        $compext      extension used for compression type (eg: raw, gz, bz2)
+#        $splitsize    size of the files that the archive creates
+#        $sshPath      value of $Conf{SshPath},
+#        $type         set to "archive"
+#        $cmdType      set to ArchivePreUserCmd or ArchivePostUserCmd
 #
 $Conf{DumpPreUserCmd}     = undef;
 $Conf{DumpPostUserCmd}    = undef;
 $Conf{RestorePreUserCmd}  = undef;
 $Conf{RestorePostUserCmd} = undef;
+$Conf{ArchivePreUserCmd}  = undef;
+$Conf{ArchivePostUserCmd} = undef;
 
 #
 # Override the client's host name.  This allows multiple clients
@@ -1253,10 +1616,10 @@ $Conf{CgiURL} = undef;
 #   
 # Language to use.  See lib/BackupPC/Lang for the list of supported
 # languages, which include English (en), French (fr), Spanish (es),
-# and German (de).
+# German (de), Italian (it) and Dutch (nl).
 #
 # Currently the Language setting applies to the CGI interface and email
-# messages sent to users.  Log files and other text is still in English.
+# messages sent to users.  Log files and other text are still in English.
 #
 $Conf{Language} = 'en';
 
@@ -1292,27 +1655,38 @@ $Conf{CgiDateFormatMMDD} = 1;
 
 #
 # If set, the complete list of hosts appears in the left navigation
-# bar for administrators.  Otherwise, just the hosts for which the
-# user is listed in the host file (as either the user or in moreUsers)
+# bar pull-down for administrators.  Otherwise, just the hosts for which
+# the user is listed in the host file (as either the user or in moreUsers)
 # are displayed.
 #
-$Conf{CgiNavBarAdminAllHosts} = 0;
+$Conf{CgiNavBarAdminAllHosts} = 1;
 
 #
-# Header font and size for CGI interface
+# Enable/disable the search box in the navigation bar.
 #
-$Conf{CgiHeaderFontType} = 'arial';
-$Conf{CgiHeaderFontSize} = '3';
+$Conf{CgiSearchBoxEnable} = 1;
 
 #
-# Color scheme for CGI interface.  Default values give a very light blue
-# for the background navigation color, green for the header background,
-# and white for the body background.  (You call tell I should stick to
-# programming and not graphical design.)
+# Additional navigation bar links.  These appear for both regular users
+# and administrators.  This is a list of hashes giving the link (URL)
+# and the text (name) for the link.  Specifying lname instead of name
+# uses the language specific string (ie: $Lang->{lname}) instead of
+# just literally displaying name.
 #
-$Conf{CgiNavBarBgColor} = '#ddeeee';
-$Conf{CgiHeaderBgColor} = '#99cc33';
-$Conf{CgiBodyBgColor}   = '#ffffff';
+$Conf{CgiNavBarLinks} = [
+    {
+        link  => "?action=view&type=docs",
+        lname => "Documentation",    # actually displays $Lang->{Documentation}
+    },
+    {
+        link  => "http://backuppc.sourceforge.net/faq",
+        name  => "FAQ",              # displays literal "FAQ"
+    },
+    {
+        link  => "http://backuppc.sourceforge.net",
+        name  => "SourceForge",      # displays literal "SourceForge"
+    },
+];
 
 #
 # Hilight colors based on status that are used in the PC summary page.
@@ -1360,3 +1734,10 @@ $Conf{CgiExt2ContentType} = { };
 #     $Conf{CgiImageDirURL} = '/BackupPC';
 #
 $Conf{CgiImageDirURL} = '';
+
+#
+# CSS stylesheet for the CGI interface.  It is stored in the
+# $Conf{CgiImageDir} directory and accessed via the
+# $Conf{CgiImageDirURL} URL.
+#
+$Conf{CgiCSSFile} = 'BackupPC_stnd.css';
