@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 2.1.0, released 20 Jun 2004.
+# Version 2.1.1, released 13 Mar 2005.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -102,8 +102,10 @@ sub NewRequest
 	$Lang   = $bpc->Lang();
 	$ConfigMTime = $bpc->ConfigMTime();
     } elsif ( $bpc->ConfigMTime() != $ConfigMTime ) {
-        $bpc->ServerMesg("log Re-read config file because mtime changed");
-        $bpc->ServerMesg("server reload");
+	$bpc->ConfigRead();
+	%Conf   = $bpc->Conf();
+	$Lang   = $bpc->Lang();
+	$ConfigMTime = $bpc->ConfigMTime();
     }
 
     #
@@ -154,6 +156,15 @@ EOF
 	       {map {$_, 1} split(",", $Hosts->{$host}{moreUsers}) }
 	}
     }
+
+    #
+    # Untaint the host name
+    #
+    if ( $In{host} =~ /^([\w.\s-]+)$/ ) {
+	$In{host} = $1;
+    } else {
+	delete($In{host});
+    }
 }
 
 sub timeStamp2
@@ -278,6 +289,8 @@ sub GetStatusInfo
 {
     my($status) = @_;
     ServerConnect();
+    %Status = ()     if ( $status =~ /\bhosts\b/ );
+    %StatusHost = () if ( $status =~ /\bhost\(/ );
     my $reply = $bpc->ServerMesg("status $status");
     $reply = $1 if ( $reply =~ /(.*)/s );
     eval($reply);
@@ -498,7 +511,7 @@ EOF
     NavSectionTitle($Lang->{NavSectionTitle_});
     foreach my $l ( @adminLinks ) {
         if ( $PrivAdmin || !$l->{priv} ) {
-            my $txt = defined($l->{lname}) ? $Lang->{$l->{lname}} : $l->{name};
+            my $txt = $l->{lname} ne "" ? $Lang->{$l->{lname}} : $l->{name};
             NavLink($l->{link}, $txt);
         }
     }
