@@ -6,26 +6,68 @@
 
 # --------------------------------
 
+$Lang{Start_Archive} = "Comenzar archivado";
+$Lang{Stop_Dequeue_Archive} = "Parar/anular archivado";
 $Lang{Start_Full_Backup} = "Comenzar copia de seguridad completa";
 $Lang{Start_Incr_Backup} = "Comenzar copia de seguridad incremental";
 $Lang{Stop_Dequeue_Backup} = "Parar/anular copia de seguridad";
 $Lang{Restore} = "Restaurar";
 
+$Lang{Type_full} = "completo";
+$Lang{Type_incr} = "incremental";
+
+# -----
+
+$Lang{Only_privileged_users_can_view_admin_options} = "Slo los superusuarios pueden ver las opciones de administracin.";
+$Lang{H_Admin_Options} = "Servidor BackupPC: Opciones de administracin";
+$Lang{Admin_Options} = "Opciones de administracin";
+$Lang{Admin_Options_Page} = <<EOF;
+\${h1(qq{$Lang{Admin_Options}})}
+<br>
+\${h2("Control del Servidor")}
+<form action="\$MyURL" method="get">
+<table class="tableStnd">
+<!--<tr><td>Para el servidor:<td><input type="submit" name="action" value="Stop">-->
+  <tr><td>Actualizar configuracin del servidor:<td><input type="submit" name="action" value="Reload">
+</table>
+</form>
+<!--
+\${h2("Server Configuration")}
+<ul> 
+  <li><i>Espacio para otras opciones... e.j.,</i>
+  <li>Editar configuracin del servidor
+</ul>
+-->
+EOF
+$Lang{Unable_to_connect_to_BackupPC_server} = "Imposible conectar al servidor BackupPC",
+            "Este script CGI (\$MyURL) no puede conectar al servidor BackupPC"
+          . " en \$Conf{ServerHost} puerto \$Conf{ServerPort}.  El error"
+          . " fu: \$err.",
+            "Quiz el servidor BackupPC no est activo o hay un "
+          . " error de configuracin. Por favor informe a su administrador de sistemas.";
+$Lang{Admin_Start_Server} = <<EOF;
+\${h1(qq{$Lang{Unable_to_connect_to_BackupPC_server}})}
+<form action="\$MyURL" method="get">
+El servidor BackupPC en <tt>\$Conf{ServerHost}</tt> port <tt>\$Conf{ServerPort}</tt>
+no est en funcionamiento ahora (puede haberlo detenido o no haberlo arrancado an).<br>
+Quiere inicializarlo?
+<input type="hidden" name="action" value="startServer">
+<input type="submit" value="Start Server" name="ignore">
+</form>
+EOF
+
 # -----
 
 $Lang{H_BackupPC_Server_Status} = "Estado del Servidor BackupPC";
 
-$Lang{BackupPC_Server_Status}= <<EOF;
-\${h1(qq{$Lang{H_BackupPC_Server_Status}})}
-
-
-<p>
+$Lang{BackupPC_Server_Status_General_Info}= <<EOF;
 \${h2(\"Informacin General del servidor\")}
 
 <ul>
 <li> El PID del servidor es \$Info{pid}, en el host \$Conf{ServerHost},
      version \$Info{Version}, iniciado el \$serverStartTime.
 <li> Esta informacin de estado se ha generado el \$now.
+<li> La ltima configuracin ha sido cargada a las \$configLoadTime
 <li> La cola de PCs se activar de nuevo el \$nextWakeupTime.
 <li> Informacin adicional:
     <ul>
@@ -38,11 +80,18 @@ $Lang{BackupPC_Server_Status}= <<EOF;
             y el mximo de ayer era \$Info{DUDailyMaxPrev}%.
     </ul>
 </ul>
+EOF
+
+$Lang{BackupPC_Server_Status} = <<EOF;
+\${h1(qq{$Lang{H_BackupPC_Server_Status}})}
+
+<p>
+\$generalInfo
 
 \${h2("Trabajos en Ejecucin")}
 <p>
-<table border>
-<tr><td> Host </td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<tr class="tableheader"><td> Host </td>
     <td> Tipo </td>
     <td> Usuario </td>
     <td> Hora de Inicio </td>
@@ -56,8 +105,8 @@ $Lang{BackupPC_Server_Status}= <<EOF;
 
 \${h2("Fallos que Precisan Atencin")}
 <p>
-<table border>
-<tr><td align="center"> Host </td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<tr class="tableheader"><td align="center"> Host </td>
     <td align="center"> Tipo </td>
     <td align="center"> Usuario </td>
     <td align="center"> Ultimo Intento </td>
@@ -70,12 +119,13 @@ EOF
 
 # --------------------------------
 $Lang{BackupPC__Server_Summary} = "BackupPC: Resumen del Servidor";
+$Lang{BackupPC__Archive} = "BackupPC: Archivo";
 $Lang{BackupPC_Summary}=<<EOF;
 
 \${h1(qq{$Lang{BackupPC__Server_Summary}})}
 <p>
 Este status ha sido generado el \$now.
-<p>
+</p>
 
 \${h2("Hosts con Buenas Copias de Seguridad")}
 <p>
@@ -86,8 +136,9 @@ Il y a \$hostCntGood hosts tienen copia de seguridad, de un total de :
 <li> \$incrTot copias de seguridad incrementales con tamao total de \${incrSizeTot} GB
      (antes de agrupar y comprimir).
 </ul>
-<table border>
-<tr><td> Host </td>
+</p>
+<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<tr class="tableheader"><td> Host </td>
     <td align="center"> Usuario </td>
     <td align="center"> #Completo </td>
     <td align="center"> Completo Antig./Das </td>
@@ -99,14 +150,13 @@ Il y a \$hostCntGood hosts tienen copia de seguridad, de un total de :
     <td align="center"> Ultimo Intento </td></tr>
 \$strGood
 </table>
-<p>
-
+<br><br>
 \${h2("Hosts Sin Copias de Seguridad")}
 <p>
 Hay \$hostCntNone hosts sin copias de seguridad.
 <p>
-<table border>
-<tr><td> Host </td>
+<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<tr class="tableheader"><td> Host </td>
     <td align="center"> Usuario </td>
     <td align="center"> #Completo </td>
     <td align="center"> Completo Antig./Das </td>
@@ -120,6 +170,107 @@ Hay \$hostCntNone hosts sin copias de seguridad.
 </table>
 EOF
 
+$Lang{BackupPC_Archive} = <<EOF;
+\${h1(qq{$Lang{BackupPC__Archive}})}
+<script language="javascript" type="text/javascript">
+<!--
+
+    function checkAll(location)
+    {
+      for (var i=0;i<document.form1.elements.length;i++)
+      {
+        var e = document.form1.elements[i];
+        if ((e.checked || !e.checked) && e.name != \'all\') {
+            if (eval("document.form1."+location+".checked")) {
+                e.checked = true;
+            } else {
+                e.checked = false;
+            }
+        }
+      }
+    }
+
+    function toggleThis(checkbox)
+    {
+       var cb = eval("document.form1."+checkbox);
+       cb.checked = !cb.checked;
+    }
+
+//-->
+</script>
+
+Hay \$hostCntGood hosts que tienen copia de seguridad con un tamao total de \${fullSizeTot}GB
+<p>
+<form name="form1" method="post" action="\$MyURL">
+<input type="hidden" name="fcbMax" value="\$checkBoxCnt">
+<input type="hidden" name="type" value="1">
+<input type="hidden" name="host" value="\${EscHTML(\$archHost)}">
+<input type="hidden" name="action" value="Archive">
+<table class="tableStnd" border cellpadding="3" cellspacing="1">
+<tr class="tableheader"><td align=center> Host</td>
+    <td align="center"> User </td>
+    <td align="center"> Backup Size </td>
+\$strGood
+\$checkAllHosts
+</table>
+</form>
+<p>
+
+EOF
+
+$Lang{BackupPC_Archive2} = <<EOF;
+\${h1(qq{$Lang{BackupPC__Archive}})}
+Se va a hacer copia de seguridad de los siguientes hosts
+<ul>
+\$HostListStr
+</ul>
+<form action="\$MyURL" method="post">
+\$hiddenStr
+<input type="hidden" name="action" value="Archive">
+<input type="hidden" name="host" value="\${EscHTML(\$archHost)}">
+<input type="hidden" name="type" value="2">
+<input type="hidden" value="0" name="archive_type">
+<table class="tableStnd" border cellspacing="1" cellpadding="3">
+\$paramStr
+<tr>
+    <td colspan=2><input type="submit" value="Start the Archive" name=""></td>
+</tr>
+</form>
+</table>
+EOF
+
+$Lang{BackupPC_Archive2_location} = <<EOF;
+<tr>
+    <td>Ubicacin de archivo/Dispositivo</td>
+    <td><input type="text" value="\$ArchiveDest" name="archive_device"></td>
+</tr>
+EOF
+
+$Lang{BackupPC_Archive2_compression} = <<EOF;
+<tr>
+    <td>Compression</td>
+    <td>
+    <input type="radio" value="0" name="compression" \$ArchiveCompNone>None<br>
+    <input type="radio" value="1" name="compression" \$ArchiveCompGzip>gzip<br>
+    <input type="radio" value="2" name="compression" \$ArchiveCompBzip2>bzip2
+    </td>
+</tr>
+EOF
+
+$Lang{BackupPC_Archive2_parity} = <<EOF;
+<tr>
+    <td>Porcentaje de datos de paridad (0 = deshabilitado, 5 = normal)</td>
+    <td><input type="numeric" value="\$ArchivePar" name="par"></td>
+</tr>
+EOF
+
+$Lang{BackupPC_Archive2_split} = <<EOF;
+<tr>
+    <td>Dividir resultado en</td>
+    <td><input type="numeric" value="\$ArchiveSplit" name="splitsize">Megabytes</td>
+</tr>
+EOF
+
 # -----------------------------------
 $Lang{Pool_Stat} = <<EOF;
         <li>El grupo tiene \${poolSize}GB incluyendo \$info->{"\${name}FileCnt"} archivos
@@ -182,38 +333,42 @@ EOF
 # --------------------------------
 $Lang{Only_privileged_users_can_view_queues_} = "Slo los administradores pueden ver las colas.";
 # --------------------------------
+$Lang{Only_privileged_users_can_archive} = "Slo los administradores pueden archivar.";
+# --------------------------------
 $Lang{BackupPC__Queue_Summary} = "BackupPC: Resumen de la Cola";
 # --------------------------------
 $Lang{Backup_Queue_Summary} = <<EOF;
 \${h1("Resumen de la Cola de Copias de Seguridad")}
-<p>
+<br><br>
 \${h2("Resumen de la Cola de Usuarios")}
 <p>
 Las siguientes solicitudes de usuarios estn actualmente en cola:
-<table border>
-<tr><td> Host </td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td> Host </td>
     <td> Hora Sol. </td>
     <td> Usuario </td></tr>
 \$strUser
 </table>
-<p>
+<br><br>
 
 \${h2("Resumen de Cola en Segundo Plano")}
 <p>
 Las siguientes solicitudes en segundo plano estn actualmente en cola:
-<table border>
-<tr><td> Host </td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td> Host </td>
     <td> Hora Sol. </td>
     <td> Usuario </td></tr>
 \$strBg
 </table>
-<p>
-
+<br><br>
 \${h2("Resumen de Cola de Comandos")}
 <p>
 Los siguientes comandos estn actualmente en cola:
-<table border>
-<tr><td> Host </td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td> Host </td>
     <td> Hora Sol. </td>
     <td> Usuario </td>
     <td> Comando </td></tr>
@@ -242,8 +397,8 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Historial de Archivo de Registro"
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Historial de Archivo de Registro \$hdr")}
 <p>
-<table border>
-<tr><td align="center"> File </td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td align="center"> File </td>
     <td align="center"> Size </td>
     <td align="center"> Hora Modificacin </td></tr>
 \$str
@@ -254,8 +409,8 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Resumen de Mensajes Recientes (Orden de tiempo inverso)")}
 <p>
-<table border>
-<tr><td align="center"> Destinatario </td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td align="center"> Destinatario </td>
     <td align="center"> Host </td>
     <td align="center"> Hora </td>
     <td align="center"> Asunto </td></tr>
@@ -270,25 +425,29 @@ $Lang{Browse_backup__num_for__host} = "BackupPC: Hojear copia de seguridad \$num
 # ------------------------------
 $Lang{Restore_Options_for__host} = "BackupPC: Opciones de restauracin para \$host";
 $Lang{Restore_Options_for__host2} = <<EOF;
+\${h1("Opciones de restauracin para \$host")}
 <p>
 Ha seleccionado los siguientes archivos/directorios de
 la unidad \$share, copia nmero #\$num:
 <ul>
 \$fileListStr
 </ul>
-<p>
+</p><p>
 Tiene tres opciones para restaurar estos archivos/directorios.
 Por favor, seleccione una de las siguientes opciones.
-<p>
+</p>
 \${h2("Opcin 1: Restauracin Directa")}
 <p>
+EOF
+
+$Lang{Restore_Options_for__host_Option1} = <<EOF;
 Puede empezar un proceso que restaurar estos archivos directamente en
 \$host.
-<p>
+</p><p>
 <b>Atencin!:</b> Cualquier archivo existente con el mismo nombre que los que ha
 seleccionado ser sobreescrito!
-
-<form action="\$MyURL" method="post">
+</p>
+<form action="\$MyURL" method="post" name="direct">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="type" value="3">
@@ -297,8 +456,17 @@ seleccionado ser sobreescrito!
 <table border="0">
 <tr>
     <td>Restaurar los archivos al host</td>
-    <td><input type="text" size="40" value="\${EscHTML(\$host)}"
-	 name="hostDest"></td>
+    <td><!--<input type="text" size="40" value="\${EscHTML(\$host)}"
+         name="hostDest">-->
+         <select name="hostDest" onChange="document.direct.shareDest.value=''">
+         \$hostDestSel
+         </select>
+         <script language="Javascript">
+         function myOpen(URL) {
+                window.open(URL,'','width=500,height=400');
+         }
+         </script>
+         <!--<a href="javascript:myOpen('\$MyURL?action=findShares&host='+document.direct.hostDest.options.value)">Search for available shares (NOT IMPLEMENTED)</a>--></td>
 </tr><tr>
     <td>Restaurar los archivos a la unidad</td>
     <td><input type="text" size="40" value="\${EscHTML(\$share)}"
@@ -313,20 +481,25 @@ seleccionado ser sobreescrito!
 </form>
 EOF
 
+$Lang{Restore_Options_for__host_Option1_disabled} = <<EOF;
+Se ha deshabilitado la restauracin directa para el host \${EscHTML(\$hostDest)}.
+Por favor seleccione una de las otras opciones de restauracin.
+EOF
+
 # ------------------------------
 $Lang{Option_2__Download_Zip_archive} = <<EOF;
-
+<p>
 \${h2("Opcin 2: Descargar archivo Zip")}
 <p>
 Puede descargar un archivo comprimido (.zip) conteniendo todos los archivos y directorios que
 ha seleccionado.  Despus puede hacer uso de una aplicacin local, como WinZip,
 para ver o extraer cualquiera de los archivos.
-<p>
+</p><p>
 <b>Atencin!:</b> Dependiendo de que archivos/carpetas haya seleccionado,
-este archivo puede ser muy grande. Podra tardar muchos minutos
+este archivo puede ser muy grande. Podra tardar muchos minutos en
 crear y transferir el archivo. Adems necesitar suficiente espacio el el disco
 local para almacenarlo.
-<p>
+</p>
 <form action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
 <input type="hidden" name="num" value="\$num">
@@ -347,13 +520,14 @@ EOF
 # ------------------------------
 
 $Lang{Option_2__Download_Zip_archive2} = <<EOF;
+<p>
 \${h2("Opcin 2: Descargar archivo Zip")}
 <p>
 El programa Archive::Zip no est instalado, de modo que no podr descargar un
 archivo comprimido zip.
 Por favor, solicite a su administrador de sistemas que instale Archive::Zip de
 <a href="http://www.cpan.org">www.cpan.org</a>.
-<p>
+</p>
 EOF
 
 
@@ -364,12 +538,12 @@ $Lang{Option_3__Download_Zip_archive} = <<EOF;
 Puede descargar un archivo comprimido (.Tar) conteniendo todos los archivos y
 directorios que ha seleccionado. Despus puede hacer uso de una aplicacin
 local, como Tar o WinZip,para ver o extraer cualquiera de los archivos.
-<p>
+</p><p>
 <b>Atencin!:</b> Dependiendo de que archivos/carpetas haya seleccionado,
 este archivo puede ser muy grande. Podra tardar muchos minutos
 crear y transferir el archivo. Adems necesitar suficiente espacio el el disco
 local para almacenarlo.
-<p>
+</p>
 <form action="\$MyURL" method="post">
 <input type="hidden" name="host" value="\${EscHTML(\$host)}">
 <input type="hidden" name="num" value="\$num">
@@ -386,7 +560,7 @@ EOF
 
 
 # ------------------------------
-$Lang{Restore_Confirm_on__host} = "BackupPC: Restore Confirm on \$host";
+$Lang{Restore_Confirm_on__host} = "BackupPC: Confirme restauracin en \$host";
 
 $Lang{Are_you_sure} = <<EOF;
 \${h1("Est seguro?")}
@@ -408,7 +582,7 @@ la copia de seguridad nmero \$num:
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="type" value="4">
 \$hiddenStr
-Do you really want to do this?
+Realmente quiere hacer esto?
 <input type="submit" value="\$In{action}" name="action">
 <input type="submit" value="No" name="">
 </form>
@@ -422,7 +596,13 @@ $Lang{Reply_from_server_was___reply} = <<EOF;
 <p>
 La respuesta del servidor fu: \$reply
 <p>
-Go back to <a href="\$MyURL?host=\$hostDest">\$hostDest home page</a>.
+volver a <a href="\$MyURL?host=\$hostDest">\$hostDest home page</a>.
+EOF
+
+$Lang{BackupPC_Archive_Reply_from_server} = <<EOF;
+\${h1(\$str)}
+<p>
+La respuesta del servidor fu: \$reply
 EOF
 
 # -------------------------
@@ -435,7 +615,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <ul>
 \$statusStr
 </ul>
-
+</p>
 \${h2("Acciones del Usuario")}
 <p>
 <form action="\$MyURL" method="get">
@@ -444,12 +624,13 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <input type="submit" value="$Lang{Start_Full_Backup}" name="action">
 <input type="submit" value="$Lang{Stop_Dequeue_Backup}" name="action">
 </form>
-
+</p>
 \${h2("Resumen de Copia de Seguridad")}
 <p>
 Haga click en el nmero de copia de seguridad para revisar y restaurar archivos.
-<table border>
-<tr><td align="center"> Copia N </td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<tr class="tableheader"><td align="center"> Copia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Completo </td>
     <td align="center"> Fecha Inicio </td>
@@ -462,11 +643,12 @@ Haga click en el nmero de copia de seguridad para revisar y restaurar archivos.
 <p>
 
 \$restoreStr
-
+</p>
+<br><br>
 \${h2("Resumen de Errores de Transferencia")}
-<p>
-<table border>
-<tr><td align="center"> Copia N </td>
+<br><br>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td align="center"> Copia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Ver </td>
     <td align="center"> N Xfer errs </td>
@@ -476,7 +658,7 @@ Haga click en el nmero de copia de seguridad para revisar y restaurar archivos.
 </tr>
 \$errStr
 </table>
-<p>
+<br><br>
 
 \${h2("Resumen de Total/Tamao de Archivos Reutilizados")}
 <p>
@@ -484,13 +666,14 @@ Los archivos existentes son aquellos que ya estn en el lote; los nuevos son
 aquellos que se han aadido al lote.
 Los archivos vacos y los errores SMB no cuentan en las cifras de reutilizados
 ni en la de nuevos.
-<table border>
-<tr><td colspan="2"></td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totales </td>
     <td align="center" colspan="2"> Archivos Existentes </td>
     <td align="center" colspan="2"> Archivos Nuevos </td>
 </tr>
-<tr>
+<tr class="tableheader">
     <td align="center"> Copia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> N Archivos </td>
@@ -503,18 +686,19 @@ ni en la de nuevos.
 </tr>
 \$sizeStr
 </table>
-<p>
+<br><br>
 
 \${h2("Resumen de Compresin")}
 <p>
 Efectividad de compresin para los archivos ya existentes en el lote y los
 archivos nuevos comprimidos.
-<table border>
-<tr><td colspan="3"></td>
+</p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Archivos Existentes </td>
     <td align="center" colspan="3"> Archivos Nuevos </td>
 </tr>
-<tr><td align="center"> Copia N </td>
+<tr class="tableheader"><td align="center"> Copia N </td>
     <td align="center"> Tipo </td>
     <td align="center"> Nivel Comp </td>
     <td align="center"> Tamao/MB </td>
@@ -526,7 +710,29 @@ archivos nuevos comprimidos.
 </tr>
 \$compStr
 </table>
+<br><br>
+EOF
+
+$Lang{Host__host_Archive_Summary} = "BackupPC: Host \$host Archive Summary";
+$Lang{Host__host_Archive_Summary2} = <<EOF;
+\${h1("Resumen de archivo del Host \$host")}
 <p>
+\$warnStr
+<ul>
+\$statusStr
+</ul>
+
+\${h2("Acciones de usuario")}
+<p>
+<form action="\$MyURL" method="get">
+<input type="hidden" name="archivehost" value="\$host">
+<input type="hidden" name="host" value="\$host">
+<input type="submit" value="$Lang{Start_Archive}" name="action">
+<input type="submit" value="$Lang{Stop_Dequeue_Archive}" name="action">
+</form>
+
+\$ArchiveStr
+
 EOF
 
 # -------------------------
@@ -570,13 +776,21 @@ $Lang{Backup_browse_for__host} = <<EOF;
 //-->
 </script>
 
+<form name="form0" method="post" action="\$MyURL">
+<input type="hidden" name="num" value="\$num">
+<input type="hidden" name="host" value="\$host">
+<input type="hidden" name="share" value="\${EscHTML(\$share)}">
+<input type="hidden" name="action" value="browse">
 <ul>
 <li> Est revisando la copia de seguridad N\$num, que comenz hacia las \$backupTime
         (hace \$backupAge dias),
 \$filledBackup
+<li> Introduzca el directorio: <input type="text" name="dir" size="50" maxlength="4096" value="\${EscHTML(\$dir)}"> <input type="submit" value="\$Lang->{Go}" name="Submit">
 <li> Haga click en uno de los directorios de abajo para revisar sus contenidos,
-<li> Haga click en un archivo para restaurarlo.
+<li> Haga click en un archivo para restaurarlo,
+<li> Puede ver la copia de seguridad <a href="\$MyURL?action=dirHistory&host=\${EscURI(\$host)}&share=\$shareURI&dir=\$pathURI">history</a> del directorio actual.
 </ul>
+</form>
 
 \${h2("Contenido de \${EscHTML(\$dirDisplay)}")}
 <form name="form1" method="post" action="\$MyURL">
@@ -586,18 +800,15 @@ $Lang{Backup_browse_for__host} = <<EOF;
 <input type="hidden" name="fcbMax" value="\$checkBoxCnt">
 <input type="hidden" name="action" value="$Lang{Restore}">
 <br>
-<table>
+<table width="100%">
 <tr><td valign="top">
-    <!--Navigate here:-->
     <br><table align="center" border="0" cellpadding="0" cellspacing="0" bgcolor="#ffffff">
     \$dirStr
     </table>
 </td><td width="3%">
 </td><td valign="top">
-    <!--Restore files here:-->
     <br>
-    <table cellpadding="0" cellspacing="0" bgcolor="#333333"><tr><td>
-        <table border="0" width="100%" align="left" cellpadding="2" cellspacing="1">
+        <table border="0" width="100%" align="left" cellpadding="3" cellspacing="1">
         \$fileHeader
         \$topCheckAll
         \$fileStr
@@ -609,48 +820,114 @@ $Lang{Backup_browse_for__host} = <<EOF;
 This is now in the checkAll row
 <input type="submit" name="Submit" value="Restore selected files">
 -->
-</td></tr></table>
 </form>
 EOF
 
+# ------------------------------
+$Lang{DirHistory_backup_for__host} = "BackupPC: Histrico de copia de seguridad del directorio en \$host";
+
+#
+# These two strings are used to build the links for directories and
+# file versions.  Files are appended with a version number.
+#
+$Lang{DirHistory_dirLink}  = "dir";
+$Lang{DirHistory_fileLink} = "v";
+
+$Lang{DirHistory_for__host} = <<EOF;
+\${h1("Histrico de copia de seguridad del directorio en \$host")}
+<p>
+Esta pantalla muestra cada versin nica de archivos de entre todas
+las copias de seguridad:
+<ul>
+<li> Haga click en un nmero de copia de seguridad para volver al explorador de copias de seguridad,
+<li> Haga click en un vnculo de directorio (\$Lang->{DirHistory_dirLink}) para navegar
+     en ese directorio,
+<li> Haga click en un vnculo de versin de archivo (\$Lang->{DirHistory_fileLink}0,
+     \$Lang->{DirHistory_fileLink}1, ...) para descargar ese archivo,
+<li> Los archivos con diferentes contenidos entre distintas copias de seguridad tienen el mismo
+     nmero de versin,
+<li> Los archivos o directorios que no existen en una copia concreta tienen una
+     celda vaca.
+<li> Los archivos mostrados con la misma versin pueden tener diferentes atributos.
+     Seleccione el nmero de copia de seguridad para ver los atributos del archivo.
+</ul>
+
+\${h2("History of \${EscHTML(\$dirDisplay)}")}
+
+<br>
+<table cellspacing="2" cellpadding="3">
+<tr class="fviewheader"><td>Backup number</td>\$backupNumStr</tr>
+<tr class="fviewheader"><td>Backup time</td>\$backupTimeStr</tr>
+\$fileStr
+</table>
+EOF
+
 # ------------------------------
 $Lang{Restore___num_details_for__host} = "BackupPC: Detalles de la restauracin N\$num de \$host";
 
-$Lang{Restore___num_details_for__host2 } = <<EOF;
+$Lang{Restore___num_details_for__host2} = <<EOF;
 \${h1("Detalles de la restauracin N\$num de \$host")}
 <p>
-<table border>
-<tr><td> Nmero </td><td> \$Restores[\$i]{num} </td></tr>
-<tr><td> Solicitado por </td><td> \$RestoreReq{user} </td></tr>
-<tr><td> Hora Peticin </td><td> \$reqTime </td></tr>
-<tr><td> Resultado </td><td> \$Restores[\$i]{result} </td></tr>
-<tr><td> Mensaje de Error </td><td> \$Restores[\$i]{errorMsg} </td></tr>
-<tr><td> Host Origen </td><td> \$RestoreReq{hostSrc} </td></tr>
-<tr><td> N copia origen </td><td> \$RestoreReq{num} </td></tr>
-<tr><td> Unidad origen </td><td> \$RestoreReq{shareSrc} </td></tr>
-<tr><td> Host destino </td><td> \$RestoreReq{hostDest} </td></tr>
-<tr><td> Unidad destino </td><td> \$RestoreReq{shareDest} </td></tr>
-<tr><td> Hora comienzo </td><td> \$startTime </td></tr>
-<tr><td> Duracin </td><td> \$duration min </td></tr>
-<tr><td> Nmero de archivos </td><td> \$Restores[\$i]{nFiles} </td></tr>
-<tr><td> Tamao total </td><td> \${MB} MB </td></tr>
-<tr><td> Tasa de transferencia </td><td> \$MBperSec MB/sec </td></tr>
-<tr><td> Errores creacin Tar </td><td> \$Restores[\$i]{tarCreateErrs} </td></tr>
-<tr><td> Errores de transferencia </td><td> \$Restores[\$i]{xferErrs} </td></tr>
-<tr><td> Archivo registro de transferencia </td><td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="90%">
+<tr><td class="tableheader"> Nmero </td><td class="border"> \$Restores[\$i]{num} </td></tr>
+<tr><td class="tableheader"> Solicitado por </td><td class="border"> \$RestoreReq{user} </td></tr>
+<tr><td class="tableheader"> Hora Peticin </td><td class="border"> \$reqTime </td></tr>
+<tr><td class="tableheader"> Resultado </td><td class="border"> \$Restores[\$i]{result} </td></tr>
+<tr><td class="tableheader"> Mensaje de Error </td><td class="border"> \$Restores[\$i]{errorMsg} </td></tr>
+<tr><td class="tableheader"> Host Origen </td><td class="border"> \$RestoreReq{hostSrc} </td></tr>
+<tr><td class="tableheader"> N copia origen </td><td class="border"> \$RestoreReq{num} </td></tr>
+<tr><td class="tableheader"> Unidad origen </td><td class="border"> \$RestoreReq{shareSrc} </td></tr>
+<tr><td class="tableheader"> Host destino </td><td class="border"> \$RestoreReq{hostDest} </td></tr>
+<tr><td class="tableheader"> Unidad destino </td><td class="border"> \$RestoreReq{shareDest} </td></tr>
+<tr><td class="tableheader"> Hora comienzo </td><td class="border"> \$startTime </td></tr>
+<tr><td class="tableheader"> Duracin </td><td class="border"> \$duration min </td></tr>
+<tr><td class="tableheader"> Nmero de archivos </td><td class="border"> \$Restores[\$i]{nFiles} </td></tr>
+<tr><td class="tableheader"> Tamao total </td><td class="border"> \${MB} MB </td></tr>
+<tr><td class="tableheader"> Tasa de transferencia </td><td class="border"> \$MBperSec MB/sec </td></tr>
+<tr><td class="tableheader"> Errores creacin Tar </td><td class="border"> \$Restores[\$i]{tarCreateErrs} </td></tr>
+<tr><td class="tableheader"> Errores de transferencia </td><td class="border"> \$Restores[\$i]{xferErrs} </td></tr>
+<tr><td class="tableheader"> Archivo registro de transferencia </td><td class="border">
 <a href="\$MyURL?action=view&type=RestoreLOG&num=\$Restores[\$i]{num}&host=\$host">View</a>,
 <a href="\$MyURL?action=view&type=RestoreErr&num=\$Restores[\$i]{num}&host=\$host">Errors</a>
 </tr></tr>
 </table>
-<p>
+</p>
 \${h1("Lista de Archivos/Directorios")}
 <p>
-<table border>
-<tr><td>Dir/archivo original</td><td>Restaurado a</td></tr>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="100%">
+<tr class="tableheader"><td>Dir/archivo original</td><td>Restaurado a</td></tr>
 \$fileListStr
 </table>
 EOF
 
+# ------------------------------
+$Lang{Archive___num_details_for__host} = "BackupPC: Copia de seguridad #\$num .Detalles de \$host";
+
+$Lang{Archive___num_details_for__host2 } = <<EOF;
+\${h1("Copia de seguridad #\$num Detalles de \$host")}
+<p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr><td class="tableheader"> Nmero </td><td class="border"> \$Archives[\$i]{num} </td></tr>
+<tr><td class="tableheader"> Solicitado por </td><td class="border"> \$ArchiveReq{user} </td></tr>
+<tr><td class="tableheader"> Hora peticin </td><td class="border"> \$reqTime </td></tr>
+<tr><td class="tableheader"> Resultado </td><td class="border"> \$Archives[\$i]{result} </td></tr>
+<tr><td class="tableheader"> Mensaje de error </td><td class="border"> \$Archives[\$i]{errorMsg} </td></tr>
+<tr><td class="tableheader"> Hora comienzo </td><td class="border"> \$startTime </td></tr>
+<tr><td class="tableheader"> Duracin </td><td class="border"> \$duration min </td></tr>
+<tr><td class="tableheader"> Archivo registro Xfer </td><td class="border">
+<a href="\$MyURL?action=view&type=ArchiveLOG&num=\$Archives[\$i]{num}&host=\$host">View</a>,
+<a href="\$MyURL?action=view&type=ArchiveErr&num=\$Archives[\$i]{num}&host=\$host">Errors</a>
+</tr></tr>
+</table>
+<p>
+\${h1("Host list")}
+<p>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td>Host</td><td>Copia de seguridad nmero</td></tr>
+\$HostListStr
+</table>
+EOF
+
 # -----------------------------------
 $Lang{Email_Summary} = "BackupPC: Resumen de Correos";
 
@@ -661,7 +938,7 @@ $Lang{BackupPC__Lib__new_failed__check_apache_error_log} = "BackupPC::Lib->nuevo
 $Lang{Wrong_user__my_userid_is___} =  
               "Usuario errneo: mi userid es \$>, en lugar de \$uid"
             . "(\$Conf{BackupPCUser})\n";
-$Lang{Only_privileged_users_can_view_PC_summaries} = "Slo los usuarios autorizados pueden ver los resmenes de PCs.";
+# $Lang{Only_privileged_users_can_view_PC_summaries} = "Slo los usuarios autorizados pueden ver los resmenes de PCs.";
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Slo los usuarios autorizados pueden comenzar a detener las copias"
 		. " \${EscHTML(\$host)}.";
@@ -682,6 +959,8 @@ $Lang{Only_privileged_users_can_restore_backup_files} = "Slo los usuarios autori
 $Lang{Bad_host_name} = "Nombre de host errneo \${EscHTML(\$host)}";
 $Lang{You_haven_t_selected_any_files__please_go_Back_to} = "No ha seleccionado nign archivo; por favor, vuelva a"
                 . " seleccione algunos archivos.";
+$Lang{You_haven_t_selected_any_hosts} = "No ha seleccionado ningn host; por favor vuelva a"
+                . " select some hosts.";
 $Lang{Nice_try__but_you_can_t_put} = "Buen intento, pero no puede usar \'..\' en los nombres de archivo";
 $Lang{Host__doesn_t_exist} = "El Host \${EscHTML(\$In{hostDest})} no existe";
 $Lang{You_don_t_have_permission_to_restore_onto_host} = "No tiene autorizacin para restaurar en el host"
@@ -694,17 +973,12 @@ $Lang{Empty_host_name} = "Nombre de host vaco";
 $Lang{Unknown_host_or_user} = "Unknown host or user \${EscHTML(\$host)}";
 $Lang{Only_privileged_users_can_view_information_about} = "Slo los usuarios autorizados pueden ver informacin del"
                 . " host \${EscHTML(\$host)}." ;
+$Lang{Only_privileged_users_can_view_archive_information} = "Slo los administradores pueden ver informacin de archivo.";
 $Lang{Only_privileged_users_can_view_restore_information} = "Slo los usuarios autorizados pueden ver informacin de restauracin.";
 $Lang{Restore_number__num_for_host__does_not_exist} = "El nmero de restauracin \$num del host \${EscHTML(\$host)} "
 	        . " no existe.";
-
-$Lang{Unable_to_connect_to_BackupPC_server} = "Imposible conectar al servidor BackupPC",
-            "Este script CGI (\$MyURL) no puede conectar al servidor BackupPC"
-          . " en \$Conf{ServerHost} puerto \$Conf{ServerPort}.  El error"
-          . " fu: \$err.",
-            "Quiz el servidor BackupPC no est activo o hay un "
-          . " error de configuracin. Por favor informe a su administrador de sistemas.";
-
+$Lang{Archive_number__num_for_host__does_not_exist} = "La copia de seguridad \$num del host \${EscHTML(\$host)} "
+                . " no existe.";
 $Lang{Can_t_find_IP_address_for} = "No puedo encontrar la direccin IP de \${EscHTML(\$host)}";
 $Lang{host_is_a_DHCP_host} = <<EOF;
 \$host es un host DHCP y yo no conozco su direccin IP. He comprobado el
@@ -715,18 +989,17 @@ Hasta que vea \$host en una direccin DHCP concreta, slo puede
 comenzar este proceso desde la propia mquina cliente.
 EOF
 
-########################
-# ok you can do it then
-########################
+# ------------------------------------
+# !! Server Mesg !!
+# ------------------------------------
 
 $Lang{Backup_requested_on_DHCP__host} = "Copia de seguridad solicitada en DHCP \$host (\$In{hostIP}) por"
 		                      . " \$User desde \$ENV{REMOTE_ADDR}";
-
 $Lang{Backup_requested_on__host_by__User} = "Copia de seguridad solicitada en \$host por \$User";
 $Lang{Backup_stopped_dequeued_on__host_by__User} = "Copia de seguridad detenida/desprogramada en \$host por \$User";
-
 $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restauracin solicitada para el host \$hostDest, copia de seguridad #\$num,"
 	     . " por \$User desde \$ENV{REMOTE_ADDR}";
+$Lang{Archive_requested} = "Archivo solicitado por \$User desde \$ENV{REMOTE_ADDR}";
 
 # -------------------------------------------------
 # ------- Stuff that was forgotten ----------------
@@ -735,6 +1008,7 @@ $Lang{Restore_requested_to_host__hostDest__backup___num} = "Restauracin solicita
 $Lang{Status} = "Estado";
 $Lang{PC_Summary} = "Resumen PC";
 $Lang{LOG_file} = "Archivo Registro";
+$Lang{LOG_files} = "Archivos de registro";
 $Lang{Old_LOGs} = "Registros antiguos";
 $Lang{Email_summary} = "Resumen correo";
 $Lang{Config_file} = "Archivo configuracin";
@@ -742,10 +1016,12 @@ $Lang{Hosts_file} = "Archivo Hosts";
 $Lang{Current_queues} = "Colas actuales";
 $Lang{Documentation} = "Documentacin";
 
-$Lang{Host_or_User_name} = "<small>Host o usuario:</small>";
+#$Lang{Host_or_User_name} = "<small>Host o usuario:</small>";
 $Lang{Go} = "Aceptar";
 $Lang{Hosts} = "Hosts";
+$Lang{Select_a_host} = "Seleccione un host...";
 
+$Lang{There_have_been_no_archives} = "<h2> No ha habido archivos </h2>\n";
 $Lang{This_PC_has_never_been_backed_up} = "<h2> !Nunca se ha hecho copia de seguridad de este PC! </h2>\n";
 $Lang{This_PC_is_used_by} = "<li>This PC es utilizado por \${UserLink(\$user)}";
 
@@ -803,28 +1079,38 @@ EOF
 
 $Lang{Because__host_has_been_on_the_network_at_least__Conf_BlackoutGoodCnt_consecutive_times___} = <<EOF;
 <li>Dado que \$host ha estado en la red al menos \$Conf{BlackoutGoodCnt}
-veces consecutivas, no se le realizar copia de seguridad desde \$t0 hasta \$t1 en \$days.
+veces consecutivas, no se le realizar copia de seguridad desde \$blackoutStr.
 EOF
 
+$Lang{__time0_to__time1_on__days} = "\$t0 hasta \$t1 en \$days";
+
 $Lang{Backups_are_deferred_for_hours_hours_change_this_number} = <<EOF;
 <li>Las copias de seguridad se retrasarn durante \$hours hours
-(<a href=\"\$MyURL?action=Stop/Dequeue%20Backup&host=\$host\">Cambie este nmero</a>).
+(<a href=\"\$MyURL?action=\${EscURI(\$Lang->{Stop_Dequeue_Archive})}&host=\$host\">Cambie este nmero</a>).
 EOF
 
 $Lang{tryIP} = " y \$StatusHost{dhcpHostIP}";
 
-$Lang{Host_Inhost} = "Host \$In{host}";
+#$Lang{Host_Inhost} = "Host \$In{host}";
 
 $Lang{checkAll} = <<EOF;
-<tr bgcolor="#ffffcc"><td>
+<tr><td class="fviewborder">
 <input type="checkbox" name="allFiles" onClick="return checkAll('allFiles');">&nbsp;Seleccionar todo
-</td><td colspan="5" align="center">
+</td><td colspan="5" align="center" class="fviewborder">
 <input type="submit" name="Submit" value="Restaurar los archivos seleccionados">
 </td></tr>
 EOF
 
+$Lang{checkAllHosts} = <<EOF;
+<tr><td class="fviewborder">
+<input type="checkbox" name="allFiles" onClick="return checkAll('allFiles');">&nbsp;Seleccionar todo
+</td><td colspan="2" align="center" class="fviewborder">
+<input type="submit" name="Submit" value="Archivar los hosts seleccionados">
+</td></tr>
+EOF
+
 $Lang{fileHeader} = <<EOF;
-    <tr bgcolor="\$Conf{CgiHeaderBgColor}"><td align=center> Nombre</td>
+    <tr class="fviewheader"><td align=center> Nombre</td>
        <td align="center"> Tipo</td>
        <td align="center"> Modo</td>
        <td align="center"> N</td>
@@ -834,6 +1120,7 @@ $Lang{fileHeader} = <<EOF;
 EOF
 
 $Lang{Home} = "Principal";
+$Lang{Browse} = "Explorar copias de seguridad";
 $Lang{Last_bad_XferLOG} = "Ultimo error en registro de transferencia";
 $Lang{Last_bad_XferLOG_errors_only} = "Ultimo error en registro de transferencia (errores&nbsp;slo)";
 
@@ -842,15 +1129,15 @@ $Lang{This_display_is_merged_with_backup} = <<EOF;
 EOF
 
 $Lang{Visit_this_directory_in_backup} = <<EOF;
-<li> Explorar este directorio en copia de seguridad N\$otherDirs.
+<li> Seleccione la copia de seguridad que desea ver: <select onChange="window.location=this.value">\$otherDirs </select>
 EOF
 
 $Lang{Restore_Summary} = <<EOF;
 \${h2("Resumen de Restauracin")}
 <p>
 Haga click en el nmero de restauracin para ver sus detalles.
-<table border>
-<tr><td align="center"> Restauracin N </td>
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td align="center"> Restauracin N </td>
     <td align="center"> Resultado </td>
     <td align="right"> Fecha Inicio</td>
     <td align="right"> Dur/mins</td>
@@ -864,6 +1151,21 @@ Haga click en el nmero de restauracin para ver sus detalles.
 <p>
 EOF
 
+$Lang{Archive_Summary} = <<EOF;
+\${h2("Archive Summary")}
+<p>
+Click on the archive number for more details.
+<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<tr class="tableheader"><td align="center"> Archive# </td>
+    <td align="center"> Resultado </td>
+    <td align="right"> Hora comienzo</td>
+    <td align="right"> Dur/mins</td>
+</tr>
+\$ArchiveStr
+</table>
+<p>
+EOF
+
 $Lang{BackupPC__Documentation} = "BackupPC: Documentacion";
 
 $Lang{No} = "no";
@@ -877,8 +1179,9 @@ EOF
 #$Lang{on} = "activo";
 $Lang{off} = "inactivo";
 
-$Lang{full} = "completo";
-$Lang{incremental} = "incremental";
+$Lang{backupType_full}    = "completo";
+$Lang{backupType_incr}    = "incremental";
+$Lang{backupType_partial} = "parcial";
 
 $Lang{failed} = "fallido";
 $Lang{success} = "xito";
@@ -896,12 +1199,15 @@ $Lang{Status_link_running} = "conexin en curso";
 
 $Lang{Reason_backup_done} = "copia de seguridad realizada";
 $Lang{Reason_restore_done} = "restauracin realizada";
+$Lang{Reason_archive_done}   = "archivado realizado";
 $Lang{Reason_nothing_to_do} = "nada por hacer";
 $Lang{Reason_backup_failed} = "copia de seguridad fallida";
 $Lang{Reason_restore_failed} = "restauracin fallida";
+$Lang{Reason_archive_failed} = "ha fallado el archivado";
 $Lang{Reason_no_ping} = "no hay ping";
 $Lang{Reason_backup_canceled_by_user} = "copia cancelada por el usuario";
 $Lang{Reason_restore_canceled_by_user} = "restauracin cancelada por el usuario";
+$Lang{Reason_archive_canceled_by_user} = "archivado cancelado por el usuario";
 
 # ---------
 # Email messages
@@ -1003,3 +1309,4 @@ $Lang{howLong_not_been_backed_up} = "no se le ha realizado una copia de segurida
 $Lang{howLong_not_been_backed_up_for_days_days} = "no se le ha realizado una copia de seguridad durante \$days das";
 
 #end of lang_en.pm
+
