@@ -1259,7 +1259,7 @@ Subject: $subj
 
 Ciao $userName,
 
-e` stato effettuato correttamente il backup del tuo PC ($host) per
+non e` stato effettuato correttamente il backup del tuo PC ($host) per
 $days giorni.  Dal $firstTime fino a $days fa sono stati eseguiti con
 successo $numBackups backup.  I backup dei PC dovrebbero avvenire
 automaticamente quando il tuo PC e` connesso alla rete.
